@@ -1,10 +1,10 @@
 package Net::DNS::RR;
 
 #
-# $Id: RR.pm 1068 2012-12-06 10:38:51Z willem $
+# $Id: RR.pm 1094 2012-12-27 21:35:09Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1068 $)[1];
+$VERSION = (qw$LastChangedRevision: 1094 $)[1];
 
 
 =head1 NAME
@@ -55,12 +55,11 @@ error message and execution will be terminated.
 sub new {
 	my ($class) = @_;
 
-	if (COMPATIBLE) {
-		return &_new_from_rdata if ref $_[1];		# resolve new() usage conflict
-		return scalar @_ > 2 ? &new_hash : &new_string; # avoid exception trap/reraise
-	}
+	return &_new_from_rdata if COMPATIBLE && ref $_[1];	# resolve new() usage conflict
 
-	return eval { scalar @_ > 2 ? &new_hash : &new_string; } || croak "${@}new $class( ... )";
+	my $rr = eval { scalar @_ > 2 ? &new_hash : &new_string; };
+	croak "${@}new $class( ... )" if $@;
+	return $rr;
 }
 
 
@@ -91,7 +90,7 @@ using appropriate RFC4291 or RFC4632 IP address/prefix notation.
 
 =cut
 
-my $CLASS_REGEX = join '|', 'CLASS\d+', keys %classbyname;
+my $CLASS_REGEX = join '|', sort( keys %classbyname ), 'CLASS\d+';
 my %dnssectype = map { ( $_, 1 ) } qw(DLV DNSKEY DS KEY NSEC NSEC3 NSEC3PARAM NXT RRSIG SIG);
 
 sub new_string {
@@ -104,11 +103,11 @@ sub new_string {
 	s/\\'/\\039/g;						# disguise escaped single quote
 	s/\\;/\\059/g;						# disguise escaped semicolon
 	s/\n(\S)/$1/g if COMPATIBLE;				# gloss over syntax errors in Net::DNS::SEC test data
-	my @token = grep defined && length, split /("[^"]*"|'[^']*')|;[^\n]*\n?|[()]|\s+/;
+	my @token = grep defined && length, split /("[^"]*"|'[^']*')|;[^\n]*|[()]|\s+/;
 
 	my $name    = shift @token;				# name [ttl] [class] type ...
 	my $ttl	    = shift @token if @token && $token[0] =~ /^\d/;
-	my $rrclass = shift @token if @token && $token[0] =~ /^($CLASS_REGEX)$/io;
+	my $rrclass = shift @token if @token > 1 && $token[0] =~ /^($CLASS_REGEX)$/o;
 	$ttl = shift @token if @token && $token[0] =~ /^\d/;	# name [class] [ttl] type ...
 	my $rrtype = shift(@token) || croak 'unable to parse RR string';
 
@@ -404,6 +403,7 @@ Resource record time to live in seconds.
 # published API.  These are required for parsing BIND zone files but
 # should not be used in other contexts.
 my %unit = ( W => 604800, D => 86400, H => 3600, M => 60, S => 1 );
+%unit = ( %unit, map { /\D/ ? lc($_) : $_ } %unit );
 
 sub ttl {
 	my $self  = shift;
@@ -412,7 +412,7 @@ sub ttl {
 	return $self->{ttl} || 0 unless defined $value;		# avoid defining rr->{ttl}
 
 	my $ttl = 0;
-	my %time = reverse split /(\D)\D*/, uc($value) . 'S';
+	my %time = reverse split /(\D)\D*/, $value . 'S';
 	while ( my ( $u, $t ) = each %time ) {
 		my $s = $unit{$u} || croak qq(bad time unit "$u");
 		$ttl += $s > 1 ? $t * $s : $t;
@@ -625,8 +625,10 @@ sub format_rdata {				## format rdata portion of RR string
 
 
 sub parse_rdata {				## parse RR attributes in argument list
-	my ( $self, @rdata ) = @_;
-	croak join ' ', 'zone file representation not defined for', $self->type if @rdata;
+	my $self = shift;
+	return unless shift;
+	die join ' ', $self->type, 'not implemented' if ref($self) eq __PACKAGE__;
+	die join ' ', 'zone file representation not defined for', $self->type;
 }
 
 
@@ -734,6 +736,7 @@ sub _new_from_rdata {				## decode rdata from wire-format byte string
 
 sub new_from_string {				## parse RR attributes in argument list
 	my ( $class, $self, undef, @parse ) = @_;		# new_from_string() is a misnomer
+	confess 'new_from_string() deprecated' unless ref($self);
 	$self->parse_rdata(@parse);				# string already parsed in new_string()
 	return $self;
 }
