@@ -1,10 +1,10 @@
 package Net::DNS::ZoneFile;
 
 #
-# $Id: ZoneFile.pm 1068 2012-12-06 10:38:51Z willem $
+# $Id: ZoneFile.pm 1094 2012-12-27 21:35:09Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1068 $)[1];
+$VERSION = (qw$LastChangedRevision: 1094 $)[1];
 
 
 =head1 NAME
@@ -139,7 +139,7 @@ sub read {
 
 				# construct RR object with context specific dynamically scoped $ORIGIN
 				my $context = $self->{context};
-				my $record = &$context( sub { new_string Net::DNS::RR($_) } );
+				my $record = &$context( sub { Net::DNS::RR->new_string($_) } );
 
 				$self->{class} ||= $record->class;    # propagate RR class
 				$record->class( $self->{class} );
@@ -378,7 +378,7 @@ sub DESTROY { }				## Avoid tickling AUTOLOAD (in cleanup)
 			my $s = _format( $instant, split /[,]/, $1 );
 			s/\$\{$1\}/$s/g;
 		}
-		s/\$/$instant/g;				# unqualified $
+		s/\$/_format($instant)/eg;			# unqualified $
 		return $_;
 	}
 
@@ -437,7 +437,7 @@ sub DESTROY { }				## Avoid tickling AUTOLOAD (in cleanup)
 				s/\\\\/\\092/g;			# disguise escaped escape
 				s/\\"/\\034/g;			# disguise escaped double quote
 				s/\\;/\\059/g;			# disguise escaped semicolon
-				my @token = grep defined && length, split /("[^"]*")|;[^\n]*|([()])|\s+/;
+				my @token = grep defined && length, split /(^\s)|("[^"]*")|;[^\n]*|([()])|\s+/;
 				last unless grep $_ eq '(', @token;
 				last if grep $_ eq ')', @token;
 				$_ = "@token " . <$fh>;
@@ -461,6 +461,7 @@ sub DESTROY { }				## Avoid tickling AUTOLOAD (in cleanup)
 				$self->{ttl} = Net::DNS::RR::ttl( {}, $ttl );
 			} elsif (/^\$GENERATE/) {		# directive
 				my ( undef, $range, @template ) = split;
+				die '$GENERATE incomplete' unless $range;
 				$self->_generate( $range, "@template\n" );
 				$fh = $self->{handle};
 			} elsif (/^\$/) {			# unrecognised
